PEP: 478 Title: Python 3.5 Release Schedule Version: $Revision$
Last-Modified: $Date$ Author: Larry Hastings <larry@hastings.org>
Status: Active Type: Informational Content-Type: text/x-rst Created:
22-Sep-2014 Python-Version: 3.5

Abstract
========

This document describes the development and release schedule for Python
3.5. The schedule primarily concerns itself with PEP-sized items.

.. Small features may be added up to the first beta release. Bugs may be
fixed until the final release, which is planned for September 2015.

Release Manager and Crew
========================

-   3.5 Release Manager: Larry Hastings
-   Windows installers: Steve Dower
-   Mac installers: Ned Deily
-   Documentation: Georg Brandl

Release Schedule
================

The releases so far:

-   3.5.0 alpha 1: February 8, 2015
-   3.5.0 alpha 2: March 9, 2015
-   3.5.0 alpha 3: March 29, 2015
-   3.5.0 alpha 4: April 19, 2015
-   3.5.0 beta 1: May 24, 2015 (Beta 1 is also "feature freeze"--no new
    features beyond this point.)
-   3.5.0 beta 2: May 31, 2015
-   3.5.0 beta 3: July 5, 2015
-   3.5.0 beta 4: July 26, 2015
-   3.5.0 release candidate 1: August 10, 2015
-   3.5.0 release candidate 2: August 25, 2015
-   3.5.0 release candidate 3: September 7, 2015
-   3.5.0 final: September 13, 2015
-   3.5.1 release candidate 1: November 22, 2015
-   3.5.1 final: December 6, 2015
-   3.5.2 release candidate 1: Sunday, June 12, 2016
-   3.5.2 final: Sunday, June 26, 2016
-   3.5.3 candidate 1: January 2, 2017
-   3.5.3 final: January 17, 2017
-   3.5.4 candidate 1: July 25, 2017
-   3.5.4 final: August 8, 2017
-   3.5.5 candidate 1: January 23, 2018
-   3.5.5 final: February 4, 2018
-   3.5.6 candidate 1: July 19, 2018
-   3.5.6 final: August 2, 2018
-   3.5.7 candidate 1: March 4, 2019
-   3.5.7 final: March 18, 2019
-   3.5.8 candidate 1: September 9, 2019
-   3.5.8 candidate 2: October 12, 2019
-   3.5.9 final: November 1, 2019
-   3.5.10 rc1: August 21, 2020
-   3.5.10 final: September 5, 2020

.. There are no specific plans for the next release of Python 3.5.

.. Planned future releases:

There are no specific plans for the next release of Python 3.5. Note
that Python 3.5 will no longer be supported after September 2020.
Therefore, 3.5.10 may be the final release of Python 3.5.

Features for 3.5
================

-   PEP 441, improved Python zip application support
-   PEP 448, additional unpacking generalizations
-   PEP 461, "%-formatting" for bytes and bytearray objects
-   PEP 465, a new operator ("@") for matrix multiplication
-   PEP 471, os.scandir(), a fast new directory traversal function
-   PEP 475, adding support for automatic retries of interrupted system
    calls
-   PEP 479, change StopIteration handling inside generators
-   PEP 484, the typing module, a new standard for type annotations
-   PEP 485, math.isclose(), a function for testing approximate equality
-   PEP 486, making the Windows Python launcher aware of virtual
    environments
-   PEP 488, eliminating .pyo files
-   PEP 489, a new and improved mechanism for loading extension modules
-   PEP 492, coroutines with async and await syntax

Copyright
=========

This document has been placed in the public domain.

 .. Local Variables: mode: indented-text indent-tabs-mode: nil
sentence-end-double-space: t fill-column: 70 coding: utf-8 End:
